@@ -46,13 +46,7 @@ class Header
      * @var Menu
      */
     private $menu;
-    /**
-     * Whether to offer the option of importing user settings
-     *
-     * @access private
-     * @var bool
-     */
-    private $userprefsOfferImport;
+
     /**
      * The page title
      *
@@ -141,15 +135,6 @@ class Header
         $this->scripts = new Scripts();
         $this->addDefaultScripts();
         $this->headerIsSent = false;
-        // if database storage for user preferences is transient,
-        // offer to load exported settings from localStorage
-        // (detection will be done in JavaScript)
-        $this->userprefsOfferImport = false;
-        if ($GLOBALS['PMA_Config']->get('user_preferences') === 'session'
-            && ! isset($_SESSION['userprefs_autoload'])
-        ) {
-            $this->userprefsOfferImport = true;
-        }
 
         $this->userPreferences = new UserPreferences();
     }
@@ -168,7 +153,6 @@ class Header
         $this->scripts->addFile('vendor/bootstrap/bootstrap.bundle.min.js');
         $this->scripts->addFile('vendor/jquery/jquery-ui.min.js');
         $this->scripts->addFile('vendor/js.cookie.js');
-        $this->scripts->addFile('vendor/jquery/jquery.mousewheel.js');
         $this->scripts->addFile('vendor/jquery/jquery.validate.js');
         $this->scripts->addFile('vendor/jquery/jquery-ui-timepicker-addon.js');
         $this->scripts->addFile('vendor/jquery/jquery.ba-hashchange-2.0.js');
@@ -176,21 +160,18 @@ class Header
         $this->scripts->addFile('menu_resizer.js');
 
         // Cross-framing protection
+        // At this point browser settings are not merged
+        // this is good that we only use file configuration for this protection
         if ($GLOBALS['cfg']['AllowThirdPartyFraming'] === false) {
             $this->scripts->addFile('cross_framing_protection.js');
         }
 
         $this->scripts->addFile('rte.js');
-        if ($GLOBALS['cfg']['SendErrorReports'] !== 'never') {
-            $this->scripts->addFile('vendor/tracekit.js');
-            $this->scripts->addFile('error_report.js');
-        }
 
         // Here would not be a good place to add CodeMirror because
         // the user preferences have not been merged at this point
 
         $this->scripts->addFile('messages.php', ['l' => $GLOBALS['lang']]);
-        $this->scripts->addCode($this->getVariablesForJavaScript());
         $this->scripts->addFile('config.js');
         $this->scripts->addFile('doclinks.js');
         $this->scripts->addFile('functions.js');
@@ -198,12 +179,7 @@ class Header
         $this->scripts->addFile('indexes.js');
         $this->scripts->addFile('common.js');
         $this->scripts->addFile('page_settings.js');
-        if ($GLOBALS['cfg']['enable_drag_drop_import'] === true) {
-            $this->scripts->addFile('drag_drop_import.js');
-        }
-        if (! $GLOBALS['PMA_Config']->get('DisableShortcutKeys')) {
-            $this->scripts->addFile('shortcuts_handler.js');
-        }
+
         $this->scripts->addCode($this->getJsParamsCode());
     }
 
@@ -398,7 +374,7 @@ class Header
         $version = self::getVersionParameter();
 
         // The user preferences have been merged at this point
-        // so we can conditionally add CodeMirror
+        // so we can conditionally add CodeMirror, other scripts and settings
         if ($GLOBALS['cfg']['CodemirrorEnable']) {
             $this->scripts->addFile('vendor/codemirror/lib/codemirror.js');
             $this->scripts->addFile('vendor/codemirror/mode/sql/sql.js');
@@ -413,13 +389,36 @@ class Header
             }
         }
 
+        if ($GLOBALS['cfg']['SendErrorReports'] !== 'never') {
+            $this->scripts->addFile('vendor/tracekit.js');
+            $this->scripts->addFile('error_report.js');
+        }
+        if ($GLOBALS['cfg']['enable_drag_drop_import'] === true) {
+            $this->scripts->addFile('drag_drop_import.js');
+        }
+        if (! $GLOBALS['PMA_Config']->get('DisableShortcutKeys')) {
+            $this->scripts->addFile('shortcuts_handler.js');
+        }
+
+        $this->scripts->addCode($this->getVariablesForJavaScript());
+
         $this->scripts->addCode(
             'ConsoleEnterExecutes='
             . ($GLOBALS['cfg']['ConsoleEnterExecutes'] ? 'true' : 'false')
         );
         $this->scripts->addFiles($this->console->getScripts());
 
-        if ($this->userprefsOfferImport) {
+        // if database storage for user preferences is transient,
+        // offer to load exported settings from localStorage
+        // (detection will be done in JavaScript)
+        $userprefsOfferImport = false;
+        if ($GLOBALS['PMA_Config']->get('user_preferences') === 'session'
+            && ! isset($_SESSION['userprefs_autoload'])
+        ) {
+            $userprefsOfferImport = true;
+        }
+
+        if ($userprefsOfferImport) {
             $this->scripts->addFile('config.js');
         }
 
@@ -435,7 +434,7 @@ class Header
         $customHeader = Config::renderHeader();
 
         // offer to load user preferences from localStorage
-        if ($this->userprefsOfferImport) {
+        if ($userprefsOfferImport) {
             $loadUserPreferences = $this->userPreferences->autoloadGetHeader();
         }
 
@@ -709,7 +708,7 @@ class Header
         $maxInputVarsValue = $maxInputVars === false || $maxInputVars === '' ? 'false' : (int) $maxInputVars;
 
         return $this->template->render('javascript/variables', [
-            'first_day_of_calendar' => $cfg['FirstDayOfCalendar'],
+            'first_day_of_calendar' => $cfg['FirstDayOfCalendar'] ?? 0,
             'theme_image_path' => $PMA_Theme !== null ? $PMA_Theme->getImgPath() : '',
             'max_input_vars' => $maxInputVarsValue,
         ]);
