@@ -752,7 +752,6 @@ class ConfigTest extends AbstractTestCase
         $defines = [
             'PMA_VERSION',
             'PMA_MAJOR_VERSION',
-            'PMA_IS_WINDOWS',
             'PMA_IS_GD2',
             'PMA_USR_OS',
             'PMA_USR_BROWSER_VER',
@@ -1211,6 +1210,7 @@ class ConfigTest extends AbstractTestCase
             'host' => '',
             'controluser' => 'u2',
             'controlpass' => 'p2',
+            'hide_connection_errors' => false,
         ];
         $cfg_ssl = [
             'user' => 'u',
@@ -1219,6 +1219,7 @@ class ConfigTest extends AbstractTestCase
             'ssl' => true,
             'controluser' => 'u2',
             'controlpass' => 'p2',
+            'hide_connection_errors' => false,
         ];
         $cfg_control_ssl = [
             'user' => 'u',
@@ -1227,6 +1228,7 @@ class ConfigTest extends AbstractTestCase
             'control_ssl' => true,
             'controluser' => 'u2',
             'controlpass' => 'p2',
+            'hide_connection_errors' => false,
         ];
 
         return [
@@ -1247,6 +1249,7 @@ class ConfigTest extends AbstractTestCase
                         'compress' => false,
                         'controluser' => 'u2',
                         'controlpass' => 'p2',
+                        'hide_connection_errors' => false,
                     ],
                 ],
             ],
@@ -1263,6 +1266,7 @@ class ConfigTest extends AbstractTestCase
                         'port' => 0,
                         'ssl' => false,
                         'compress' => false,
+                        'hide_connection_errors' => false,
                     ],
                 ],
             ],
@@ -1283,6 +1287,7 @@ class ConfigTest extends AbstractTestCase
                         'compress' => false,
                         'controluser' => 'u2',
                         'controlpass' => 'p2',
+                        'hide_connection_errors' => false,
                     ],
                 ],
             ],
@@ -1299,6 +1304,7 @@ class ConfigTest extends AbstractTestCase
                         'port' => 0,
                         'ssl' => true,
                         'compress' => false,
+                        'hide_connection_errors' => false,
                     ],
                 ],
             ],
@@ -1320,6 +1326,7 @@ class ConfigTest extends AbstractTestCase
                         'controluser' => 'u2',
                         'controlpass' => 'p2',
                         'control_ssl' => true,
+                        'hide_connection_errors' => false,
                     ],
                 ],
             ],
@@ -1336,6 +1343,7 @@ class ConfigTest extends AbstractTestCase
                         'port' => 0,
                         'ssl' => true,
                         'compress' => false,
+                        'hide_connection_errors' => false,
                     ],
                 ],
             ],
