@@ -6,8 +6,10 @@ namespace PhpMyAdmin\Tests;
 
 use PhpMyAdmin\Core;
 use PhpMyAdmin\Sanitize;
+use PhpMyAdmin\Url;
 use stdClass;
 use function hash;
+use function header;
 use function htmlspecialchars;
 use function mb_strpos;
 use function ob_end_clean;
@@ -15,6 +17,7 @@ use function ob_get_contents;
 use function ob_start;
 use function preg_quote;
 use function serialize;
+use function str_repeat;
 
 class CoreTest extends AbstractNetworkTestCase
 {
@@ -33,6 +36,7 @@ class CoreTest extends AbstractNetworkTestCase
         $GLOBALS['db'] = '';
         $GLOBALS['table'] = '';
         $GLOBALS['PMA_PHP_SELF'] = 'http://example.net/';
+        $GLOBALS['PMA_Config']->set('URLQueryEncryption', false);
     }
 
     /**
@@ -521,6 +525,22 @@ class CoreTest extends AbstractNetworkTestCase
                 '8G',
                 8 * 1024 * 1024 * 1024,
             ],
+            [
+                '2048',
+                2048,
+            ],
+            [
+                '2048K',
+                2048 * 1024,
+            ],
+            [
+                '2048K',
+                2048 * 1024,
+            ],
+            [
+                '102400K',
+                102400 * 1024,
+            ],
         ];
     }
 
@@ -1421,4 +1441,115 @@ class CoreTest extends AbstractNetworkTestCase
         $this->assertArrayHasKey('test', $_POST);
         $this->assertEquals('test', $_POST['test']);
     }
+
+    public function testPopulateRequestWithEncryptedQueryParams(): void
+    {
+        global $PMA_Config;
+
+        $_SESSION = [];
+        $PMA_Config->set('URLQueryEncryption', true);
+        $PMA_Config->set('URLQueryEncryptionSecretKey', str_repeat('a', 32));
+
+        $_GET = ['pos' => '0', 'eq' => Url::encryptQuery('{"db":"test_db","table":"test_table"}')];
+        $_REQUEST = $_GET;
+
+        Core::populateRequestWithEncryptedQueryParams();
+
+        $expected = ['pos' => '0', 'db' => 'test_db', 'table' => 'test_table'];
+
+        $this->assertEquals($expected, $_GET);
+        $this->assertEquals($expected, $_REQUEST);
+    }
+
+    /**
+     * @param string[] $encrypted
+     * @param string[] $decrypted
+     *
+     * @dataProvider providerForTestPopulateRequestWithEncryptedQueryParamsWithInvalidParam
+     */
+    public function testPopulateRequestWithEncryptedQueryParamsWithInvalidParam(
+        array $encrypted,
+        array $decrypted
+    ): void {
+        global $PMA_Config;
+
+        $_SESSION = [];
+        $PMA_Config->set('URLQueryEncryption', true);
+        $PMA_Config->set('URLQueryEncryptionSecretKey', str_repeat('a', 32));
+
+        $_GET = $encrypted;
+        $_REQUEST = $encrypted;
+
+        Core::populateRequestWithEncryptedQueryParams();
+
+        $this->assertEquals($decrypted, $_GET);
+        $this->assertEquals($decrypted, $_REQUEST);
+    }
+
+    /**
+     * @return string[][][]
+     */
+    public function providerForTestPopulateRequestWithEncryptedQueryParamsWithInvalidParam(): array
+    {
+        return [
+            [[], []],
+            [['eq' => []], []],
+            [['eq' => ''], []],
+            [['eq' => 'invalid'], []],
+        ];
+    }
+
+    /**
+     * @runInSeparateProcess
+     * @preserveGlobalState disabled
+     * @requires extension xdebug
+     */
+    public function testDownloadHeader(): void
+    {
+        $GLOBALS['PMA_Config']->set('PMA_USR_BROWSER_AGENT', 'FIREFOX');
+        $GLOBALS['PMA_Config']->set('PMA_USR_BROWSER_VER', '91.0');
+
+        header('Cache-Control: private, max-age=10800');
+
+        Core::downloadHeader('test.sql', 'text/x-sql', 100, false);
+
+        // phpcs:disable SlevomatCodingStandard.Namespaces.ReferenceUsedNamesOnly.ReferenceViaFullyQualifiedName
+        $headersList = \xdebug_get_headers();
+        // phpcs:enable
+
+        $this->assertContains('Cache-Control: private, max-age=10800', $headersList);
+        $this->assertContains('Content-Description: File Transfer', $headersList);
+        $this->assertContains('Content-Disposition: attachment; filename="test.sql"', $headersList);
+        $this->assertContains('Content-type: text/x-sql;charset=UTF-8', $headersList);
+        $this->assertContains('Content-Transfer-Encoding: binary', $headersList);
+        $this->assertContains('Content-Length: 100', $headersList);
+        $this->assertNotContains('Content-Encoding: gzip', $headersList);
+    }
+
+    /**
+     * @runInSeparateProcess
+     * @preserveGlobalState disabled
+     * @requires extension xdebug
+     */
+    public function testDownloadHeader2(): void
+    {
+        $GLOBALS['PMA_Config']->set('PMA_USR_BROWSER_AGENT', 'FIREFOX');
+        $GLOBALS['PMA_Config']->set('PMA_USR_BROWSER_VER', '91.0');
+
+        header('Cache-Control: private, max-age=10800');
+
+        Core::downloadHeader('test.sql.gz', 'application/x-gzip', 0, false);
+
+        // phpcs:disable SlevomatCodingStandard.Namespaces.ReferenceUsedNamesOnly.ReferenceViaFullyQualifiedName
+        $headersList = \xdebug_get_headers();
+        // phpcs:enable
+
+        $this->assertContains('Cache-Control: private, max-age=10800', $headersList);
+        $this->assertContains('Content-Description: File Transfer', $headersList);
+        $this->assertContains('Content-Disposition: attachment; filename="test.sql.gz"', $headersList);
+        $this->assertContains('Content-Type: application/x-gzip', $headersList);
+        $this->assertContains('Content-Encoding: gzip', $headersList);
+        $this->assertContains('Content-Transfer-Encoding: binary', $headersList);
+        $this->assertNotContains('Content-Length: 0', $headersList);
+    }
 }
