@@ -58,6 +58,9 @@ class DbiDummy implements DbiExtension
      */
     private $dummyQueries = [];
 
+    /** @var array<int,string|false> */
+    private $fifoErrorCodes = [];
+
     public const OFFSET_GLOBAL = 1000;
 
     public function __construct()
@@ -97,6 +100,11 @@ class DbiDummy implements DbiExtension
         return true;
     }
 
+    public function hasUnUsedErrors(): bool
+    {
+        return $this->fifoErrorCodes !== [];
+    }
+
     public function hasUnUsedQueries(): bool
     {
         foreach ($this->filoQueries as $query) {
@@ -346,11 +354,9 @@ class DbiDummy implements DbiExtension
     /**
      * returns a string that represents the client library version
      *
-     * @param object $link connection link
-     *
      * @return string MySQL client library version
      */
-    public function getClientInfo($link)
+    public function getClientInfo()
     {
         return 'libmysql - mysqlnd x.x.x-dev (phpMyAdmin tests)';
     }
@@ -364,6 +370,12 @@ class DbiDummy implements DbiExtension
      */
     public function getError($link)
     {
+        foreach ($this->fifoErrorCodes as $i => $code) {
+            unset($this->fifoErrorCodes[$i]);
+
+            return $code;
+        }
+
         return false;
     }
 
@@ -496,7 +508,7 @@ class DbiDummy implements DbiExtension
      *
      * @return void
      *
-     * @phpstan-param (int[]|string[]|array{string: string})[]|bool $result
+     * @phpstan-param ((string|null|int|bool)[]|array{string: string})[]|bool $result
      */
     public function addResult(string $query, $result, array $columns = [], array $metadata = [])
     {
@@ -508,6 +520,21 @@ class DbiDummy implements DbiExtension
         ];
     }
 
+    /**
+     * Adds an error or false as no error to the stack
+     *
+     * @param string|false $code
+     */
+    public function addErrorCode($code): void
+    {
+        $this->fifoErrorCodes[] = $code;
+    }
+
+    public function removeDefaultResults(): void
+    {
+        $this->dummyQueries = [];
+    }
+
     /**
      * @param mixed  $link  link
      * @param string $query query
@@ -1044,6 +1071,11 @@ class DbiDummy implements DbiExtension
                     . ' WHERE TABLE_SCHEMA = \'ODS_DB\' AND TABLE_NAME = \'Shop\'',
                 'result' => [],
             ],
+            [
+                'query'  => 'SELECT TABLE_NAME FROM information_schema.VIEWS'
+                    . ' WHERE TABLE_SCHEMA = \'ODS_DB\' AND TABLE_NAME = \'Feuille 1\'',
+                'result' => [],
+            ],
             [
                 'query'  => 'SELECT TABLE_NAME FROM information_schema.VIEWS'
                     . ' WHERE TABLE_SCHEMA = \'ODS_DB\' AND TABLE_NAME = \'pma_bookmark\'',
@@ -1682,7 +1714,7 @@ class DbiDummy implements DbiExtension
                 'result' => [],
             ],
             [
-                'query'  => "SHOW TABLE STATUS FROM `my_dataset` WHERE `Name` LIKE 'company\_users%'",
+                'query'  => "SHOW TABLE STATUS FROM `my_dataset` WHERE `Name` LIKE 'company\\\\_users%'",
                 'result' => [],
             ],
             [
@@ -2296,7 +2328,7 @@ class DbiDummy implements DbiExtension
                 'result' => [['1']],
             ],
             [
-                'query' => 'SHOW TABLE STATUS FROM `PMA_db` WHERE `Name` LIKE \'PMA\_table%\'',
+                'query' => 'SHOW TABLE STATUS FROM `PMA_db` WHERE `Name` LIKE \'PMA\\\\_table%\'',
                 'columns' => ['Name'],
                 'result' => [['PMA_table']],
             ],
@@ -2350,7 +2382,7 @@ class DbiDummy implements DbiExtension
                 ],
             ],
             [
-                'query' => 'SHOW FULL COLUMNS FROM `testdb`.`mytable` LIKE \'\_id\'',
+                'query' => 'SHOW FULL COLUMNS FROM `testdb`.`mytable` LIKE \'\\\\_id\'',
                 'columns' => ['Field', 'Type', 'Collation', 'Null', 'Key', 'Default', 'Extra', 'Privileges', 'Comment'],
                 'result' => [
                     [
@@ -2482,7 +2514,7 @@ class DbiDummy implements DbiExtension
                 'result' => [],
             ],
             [
-                'query' => 'SHOW TABLE STATUS FROM `my_db` WHERE `Name` LIKE \'test\_tbl%\'',
+                'query' => 'SHOW TABLE STATUS FROM `my_db` WHERE `Name` LIKE \'test\\\\_tbl%\'',
                 'result' => [],
             ],
             [
