@@ -608,6 +608,22 @@ class TypesTest extends AbstractTestCase
                 'SOUNDEX',
                 'SPACE',
                 'SQRT',
+                'ST_GeomCollFromText',
+                'ST_GeomCollFromWKB',
+                'ST_GeomFromText',
+                'ST_GeomFromWKB',
+                'ST_LineFromText',
+                'ST_LineFromWKB',
+                'ST_MLineFromText',
+                'ST_MLineFromWKB',
+                'ST_MPointFromText',
+                'ST_MPointFromWKB',
+                'ST_MPolyFromText',
+                'ST_MPolyFromWKB',
+                'ST_PointFromText',
+                'ST_PointFromWKB',
+                'ST_PolyFromText',
+                'ST_PolyFromWKB',
                 'SYSDATE',
                 'TAN',
                 'TIME',
